@@ -36,10 +36,6 @@ class PostProcessing:
         )
         self.contact = check_existance({"contact": contact}, self)
         self.period = check_existance({"period": False}, self)
-        self.base_period_time_range = check_existance(
-            {"base_period_time_range": False}, self
-        )
-
         kwargs_to_self(kwargs, self)
         self.postproc = self.postprocessing()
 
@@ -58,18 +54,23 @@ class PostProcessing:
             return output
 
         json = {}
-        json[self.CIname] = _ijson[self.CIname]
-        json[self.CIname].update(_xjson["variable_att"])
+        json[self.IDXname] = _ijson[self.IDXname]
         json["global_att"] = _xjson["global_att"]
         try:
             json["global_att"].update(_xjson[self.project]["global_att"])
         except KeyError:
             warnings.warn(f"Project {self.project} not known.")
-        json = adjust_attributes(json, None)
+        json = adjust_attributes(json, self.repl_value)
         output = NetCDFglobalattrs(
             self,
             self.proc,
             json["global_att"],
         ).output
-
+        for attr_name, attr_value in json[self.IDXname].items():
+            output[self.CIname].attrs[attr_name] = attr_value
+        associated_files = []
+        for var_name in self.var_name:
+            associated_files += [self.ds[var_name].attrs["associated_files"]]
+        associated_files = ", ".join(associated_files)
+        output[self.CIname].attrs["associated_files"] = associated_files
         return output
