@@ -1,15 +1,25 @@
 import warnings
 
+from pyhomogenize import basics
 
-def object_attrs_to_self(obj, slf):
+
+def object_attrs_to_self(obj, slf, overwrite=True):
     """Copy object attributes to new object."""
     for attr in dir(obj):
+        if attr[0] == "_":
+            continue
+        if overwrite is False and hasattr(slf, attr):
+            continue
         if attr[0].isalpha():
             setattr(slf, attr, getattr(obj, attr))
 
 
 def kwargs_to_self(kwargs, slf):
     """Write kwargs to new object."""
+    if not hasattr(slf, "kwargs"):
+        setattr(slf, "kwargs", kwargs)
+    else:
+        slf.kwargs.update(kwargs)
     for key, value in kwargs.items():
         if not hasattr(slf, key):
             setattr(slf, key, value)
@@ -39,3 +49,9 @@ def check_existance(attr_dict, slf):
                     return value
         else:
             return value
+
+
+def get_time_range_as_str(time, fmt):
+    ts = basics().date_to_str(time[0], fmt)
+    te = basics().date_to_str(time[-1], fmt)
+    return [ts, te]
